==> apache-dolphinscheduler-3.2.0-src.tar.gz: apache-dolphinscheduler-3.2.0-src/dolphinscheduler-ui/src/locales/en_US/datasource.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

export default {
  datasource: 'DataSource',
  create_datasource: 'Create DataSource',
  choose_datasource_type: 'Choose DataSource Type',
  select: 'Select',
  search_input_tips: 'Please input the keywords',
  datasource_name: 'Datasource Name',
  datasource_name_tips: 'Please enter datasource name',
  datawarehouse: 'Datawarehouse',
  datawarehouse_tips: 'Please enter datawarehouse',
  datasource_user_name: 'Owner',
  datasource_type: 'Datasource Type',
  datasource_parameter: 'Datasource Parameter',
  description: 'Description',
  description_tips: 'Please enter description',
  create_time: 'Create Time',
  update_time: 'Update Time',
  operation: 'Operation',
  click_to_view: 'Click to view',
  delete: 'Delete',
  confirm: 'Confirm',
  delete_confirm: 'Delete?',
  cancel: 'Cancel',
  create: 'Create',
  edit: 'Edit',
  success: 'Success',
  test_connect: 'Test Connect',
  ip: 'IP',
  ip_tips: 'Please enter IP',
  port: 'Port',
  port_tips: 'Please enter port',
  database_name: 'Database Name',
  database_name_tips: 'Please enter database name',
  oracle_connect_type: 'ServiceName or SID',
  oracle_connect_type_tips: 'Please select serviceName or SID',
  oracle_service_name: 'ServiceName',
  oracle_sid: 'SID',
  compatible_mode: 'Compatible Mode',
  compatible_mode_tips: 'Please enter compatible mode',
  jdbc_connect_parameters: 'jdbc connect parameters',
  principal_tips: 'Please enter Principal',
  krb5_conf_tips:
    'Please enter the kerberos authentication parameter java.security.krb5.conf',
  keytab_username_tips:
    'Please enter the kerberos authentication parameter login.user.keytab.username',
  keytab_path_tips:
    'Please enter the kerberos authentication parameter login.user.keytab.path',
  format_tips: 'Please enter format',
  connection_parameter: 'connection parameter',
  user_name: 'User Name',
  user_name_tips: 'Please enter your username',
  user_password: 'Password',
  user_password_tips: 'Please enter your password',
  aws_region: 'Aws Region',
  aws_region_tips: 'Please enter AwsRegion',
  validation: 'Validation',
  mode_tips: 'Please select a mode',
  jdbc_format_tips: 'jdbc connection parameters is not a correct JSON format',
  database_username: 'Database Username',
  database_password: 'Database Password',
  Azure_AD_username: 'Azure AD username',
  Azure_AD_password: 'Azure AD password',
  MSIClientId: 'MSI ClientId',
  clientId: 'ClientId',
  clientSecret: 'ClientSecret',
  OAuth_token_endpoint: 'OAuth 2.0 token endpoint',
  endpoint_tips: 'Please enter OAuth Token',
  AccessKeyID: 'AccessKeyID',
  AccessKeyID_tips: 'Please input AccessKeyID',
  SecretAccessKey: 'SecretAccessKey',
  SecretAccessKey_tips: 'Please input SecretAccessKey',
  dbUser: 'DbUser',
  dbUser_tips: 'Please input DbUser'
}

==> apache-dolphinscheduler-3.4.0-src.tar.gz: apache-dolphinscheduler-3.4.0-src/dolphinscheduler-ui/src/locales/en_US/datasource.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

export default {
  datasource: 'DataSource',
  create_datasource: 'Create DataSource',
  choose_datasource_type: 'Choose DataSource Type',
  select: 'Select',
  search_input_tips: 'Please input the keywords',
  datasource_name: 'Datasource Name',
  datasource_name_tips: 'Please enter datasource name',
  datawarehouse: 'Datawarehouse',
  datawarehouse_tips: 'Please enter datawarehouse',
  datasource_user_name: 'Owner',
  datasource_type: 'Datasource Type',
  datasource_parameter: 'Datasource Parameter',
  description: 'Description',
  description_tips: 'Please enter description',
  create_time: 'Create Time',
  update_time: 'Update Time',
  operation: 'Operation',
  click_to_view: 'Click to view',
  delete: 'Delete',
  confirm: 'Confirm',
  delete_confirm: 'Delete?',
  cancel: 'Cancel',
  create: 'Create',
  edit: 'Edit',
  success: 'Success',
  test_connect: 'Test Connect',
  ip: 'IP',
  ip_tips: 'Please enter IP',
  port: 'Port',
  port_tips: 'Please enter port',
  database_name: 'Database Name',
  database_name_tips: 'Please enter database name',
  oracle_connect_type: 'ServiceName or SID',
  oracle_connect_type_tips: 'Please select serviceName or SID',
  oracle_service_name: 'ServiceName',
  oracle_sid: 'SID',
  compatible_mode: 'Compatible Mode',
  compatible_mode_tips: 'Please enter compatible mode',
  jdbc_connect_parameters: 'jdbc connect parameters',
  principal_tips: 'Please enter Principal',
  krb5_conf_tips:
    'Please enter the kerberos authentication parameter java.security.krb5.conf',
  keytab_username_tips:
    'Please enter the kerberos authentication parameter login.user.keytab.username',
  keytab_path_tips:
    'Please enter the kerberos authentication parameter login.user.keytab.path',
  format_tips: 'Please enter format',
  connection_parameter: 'connection parameter',
  user_name: 'User Name',
  user_name_tips: 'Please enter your username',
  user_password: 'Password',
  user_password_tips: 'Please enter your password',
  aws_region: 'Aws Region',
  aws_region_tips: 'Please enter AwsRegion',
  aws_access_key: 'AwsAccessKey',
  aws_access_key_tips: 'Please enter AwsAccessKey',
  aws_secret_access_key: 'AwsSecretAccessKey',
  aws_secret_access_key_tips: 'Please enter AwsSecretAccessKey',
  validation: 'Validation',
  mode_tips: 'Please select a mode',
  jdbc_format_tips: 'jdbc connection parameters is not a correct JSON format',
  database_username: 'Database Username',
  database_password: 'Database Password',
  Azure_AD_username: 'Azure AD username',
  Azure_AD_password: 'Azure AD password',
  MSIClientId: 'MSI ClientId',
  clientId: 'ClientId',
  clientSecret: 'ClientSecret',
  OAuth_token_endpoint: 'OAuth 2.0 token endpoint',
  OAuth_token_endpoint_tips: 'Please enter OAuth Token',
  AccessKeyID: 'AccessKeyID',
  AccessKeyID_tips: 'Please input AccessKeyID',
  SecretAccessKey: 'SecretAccessKey',
  SecretAccessKey_tips: 'Please input SecretAccessKey',
  dbUser: 'DbUser',
  dbUser_tips: 'Please input DbUser',
  zeppelin_rest_endpoint: 'zeppelinRestEndpoint',
  zeppelin_rest_endpoint_tips: 'Please input zeppelin restEndpoint',
  kubeConfig: 'kubeConfig',
  kubeConfig_tips: 'Please input KubeConfig',
  namespace: 'namespace',
  namespace_tips: 'Please input namespace',
  access_key_id: 'Access Key Id',
  access_key_id_tips: 'Please enter access key id',
  access_key_secret: 'Access Key Secret',
  access_key_secret_tips: 'Please enter access key secret',
  region_id: 'Region Id',
  region_id_tips: 'Please enter Region Id',
  endpoint: 'Endpoint',
  endpoint_tips: 'Please enter endpoint'
}
